pub struct CommandInfo<'a> {
pub name: &'a str,
pub description: &'a str,
}Expand description
A registered command and the description shown in platform command menus
Fields
name: &'a strCommand name, without any prefix or slash
description: &'a strDescription, or an empty string when none was given