BotBuilder

Struct BotBuilder 

pub struct BotBuilder { /* private fields */ }
Builder for constructing bots with handlers

Implementations

Source

impl BotBuilder

pub fn new() -> Self

Create a new bot builder

pub fn command<H, Args>(self, name: impl Into<String>, handler: H) -> Self
where H: IntoHandler<Args>,

Register a command handler

Handlers use the extractor/responder pattern:

// Simple handler
async fn ping() -> &'static str {
    "Pong!"
}

// With extractors
async fn greet(user: User) -> String {
    format!("Hello, {}!", user.name)
}

bot.command("ping", ping)
   .command("greet", greet)
pub fn command_with_description<H, Args>( self, name: impl Into<String>, description: impl Into<String>, handler: H, ) -> Self
where H: IntoHandler<Args>,

Register a command handler with a description

The description is used for slash command menus (e.g., Telegram’s /command list).

pub fn button<H, Args>(self, pattern: impl Into<String>, handler: H) -> Self
where H: IntoHandler<Args>,

Register a button handler with pattern matching

Pattern can end with * for prefix matching (e.g., “confirm_*”)

pub fn message<H, Args>(self, handler: H) -> Self
where H: IntoHandler<Args>,

Register a catch-all message handler

pub fn commands(&self) -> impl Iterator<Item = (&str, &str)>

Get all registered commands with their descriptions

Returns an iterator of (name, description) pairs. Commands without descriptions are included with an empty string.

pub fn find_handler( &self, event_type: &str, value: &str, ) -> Option<BoxedHandler>

Find a handler matching the event type and value